import type { BaseContract, BigNumber, BytesLike, CallOverrides, PopulatedTransaction, Signer, utils } from "ethers";
import type { FunctionFragment, Result } from "@ethersproject/abi";
import type { Listener, Provider } from "@ethersproject/providers";
import type { TypedEventFilter, TypedEvent, TypedListener, OnEvent } from "./common.js";
export interface MockInterface extends utils.Interface {
    functions: {
        "erc1155()": FunctionFragment;
        "erc20()": FunctionFragment;
        "erc721()": FunctionFragment;
    };
    getFunction(nameOrSignatureOrTopic: "erc1155" | "erc20" | "erc721"): FunctionFragment;
    encodeFunctionData(functionFragment: "erc1155", values?: undefined): string;
    encodeFunctionData(functionFragment: "erc20", values?: undefined): string;
    encodeFunctionData(functionFragment: "erc721", values?: undefined): string;
    decodeFunctionResult(functionFragment: "erc1155", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "erc20", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "erc721", data: BytesLike): Result;
    events: {};
}
export interface Mock extends BaseContract {
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: MockInterface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        erc1155(overrides?: CallOverrides): Promise<[string]>;
        erc20(overrides?: CallOverrides): Promise<[string]>;
        erc721(overrides?: CallOverrides): Promise<[string]>;
    };
    erc1155(overrides?: CallOverrides): Promise<string>;
    erc20(overrides?: CallOverrides): Promise<string>;
    erc721(overrides?: CallOverrides): Promise<string>;
    callStatic: {
        erc1155(overrides?: CallOverrides): Promise<string>;
        erc20(overrides?: CallOverrides): Promise<string>;
        erc721(overrides?: CallOverrides): Promise<string>;
    };
    filters: {};
    estimateGas: {
        erc1155(overrides?: CallOverrides): Promise<BigNumber>;
        erc20(overrides?: CallOverrides): Promise<BigNumber>;
        erc721(overrides?: CallOverrides): Promise<BigNumber>;
    };
    populateTransaction: {
        erc1155(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        erc20(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        erc721(overrides?: CallOverrides): Promise<PopulatedTransaction>;
    };
}
//# sourceMappingURL=Mock.d.ts.map